@@ -54,7 +54,7 @@ class InvalidKey(Exception):
 
 class AES:
     def __init__(self, master_key, num_rounds, key_string=True):
-        if(len(key_string)!=32):
+        if(len(master_key)!=32):
             raise InvalidKey("Invald Key Length")
         if key_string:
             mk=bytearray(master_key, 'utf-8')
