@@ -25,14 +25,15 @@ class GinVPNPlugin(HttpProxyBasePlugin):
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         super().__init__(*args, **kwargs)
         key="Vrz19NDnmgmqvJw0fm4R3Zadi7OLLVoA"
-        self.server=b'127.0.0.1'
+        self.server='127.0.0.1'
         self.port=5000
-        self.serverurl=urlparse.SplitResultBytes(scheme="http", netloc="127.0.0.1:5000", path="/", query="",fragment="")
+        self.serverurl=urlparse.SplitResultBytes(scheme="http", netloc=self.server+':'+str(self.port), path="/", query="",fragment="")
         self.aes=AES.AES(key,14)
         self.decrypt=False
 
     def before_upstream_connection(
             self, request: HttpParser) -> Optional[HttpParser]:
+        print(request.method, request.url)
         if request.method != httpMethods.CONNECT and request.method != httpMethods.TRACE:
             request_string=request.method
             if request.port==80 or request.port==8080:
@@ -54,7 +55,7 @@ class GinVPNPlugin(HttpProxyBasePlugin):
                 request.add_header(b'Content-Length',
                                    bytes_(len(request.body)))
             request.port=self.port
-            request.host=self.server
+            request.host=bytes(self.server,'utf-8')
             request.url=self.serverurl
             request.method=httpMethods.POST
         return request
@@ -66,7 +67,7 @@ class GinVPNPlugin(HttpProxyBasePlugin):
     def handle_upstream_chunk(self, chunk: memoryview) -> memoryview:
         #print("msg recieved")
         res=HttpParser.response(chunk)
-        if(res.has_header(b'zander-approved') and res.code==200):
+        if(res.has_header(b'zander-approved') and res.code==b'200'):
             self.decrypt=True
             return memoryview(b'')
         if self.decrypt:
@@ -81,6 +82,11 @@ class GinVPNPlugin(HttpProxyBasePlugin):
             for h in res_headers:
                 headers_dict[h.split(b':')[0]]=h.split(b':')[1]
             headers_dict[b'Content-Length']=bytes(str(len(res_body)), 'utf-8')
+            try:
+                del headers_dict[b'Transfer-Encoding']
+            except KeyError:
+                pass
+            print(headers_dict, '\n',bytes(res_body))
             return memoryview(build_http_response(
             status_code,body=bytes(res_body),headers=headers_dict))
         return chunk
